<?php
// initial constants
define('ADMIN_PAGE_TITLE', 'Manage Languages');
define('ADMIN_SELECTED_PAGE', 'configuration');

// includes and security
include_once('_local_auth.inc.php');

// page header
include_once('_header.inc.php');
?>

<script>
    oTable = null;
    gLanguageId = null;
    gDefaultLanguage = '';
    gEditLanguageId = null;
    $(document).ready(function(){
        // datatable
        oTable = $('#fileTable').dataTable({
            "sPaginationType": "full_numbers",
            "bServerSide": true,
            "bProcessing": true,
            "sAjaxSource": 'ajax/translation_manage.ajax.php',
            "bJQueryUI": true,
            "iDisplayLength": 25,
            "aaSorting": [[ 1, "asc" ]],
            "aoColumns" : [   
                { bSortable: false, sWidth: '3%', sName: 'file_icon', sClass: "center" },
                { sName: 'language' },
                { bSortable: false, sWidth: '10%', sClass: "center" },
                { bSortable: false, sWidth: '10%', sClass: "center" },
                { bSortable: false, sWidth: '25%', sClass: "center" }
            ],
            "fnServerData": function ( sSource, aoData, fnCallback ) {
                aoData.push( { "name": "filterText", "value": $('#filterText').val() } );
                $.ajax({
                    "dataType": 'json',
                    "type": "GET",
                    "url": "ajax/translation_manage.ajax.php",
                    "data": aoData,
                    "success": fnCallback
                });
            }
        });
        
        // update custom filter
        $('.dataTables_filter').html($('#customFilter').html());

        // dialog box
        $( "#addLanguageForm" ).dialog({
            modal: true,
            autoOpen: false,
            width: 800,
            height: 390,
            buttons: {
                "Add Language": function() {
                    processAddLanguage();
                },
                "Cancel": function() {
                    $("#addLanguageForm").dialog("close");
                }
            },
            open: function() {
                setLoader();
                loadAddLanguageForm();
                resetOverlays();
            }
        });
        
        // dialog box
        $( "#editLanguageForm" ).dialog({
            modal: true,
            autoOpen: false,
            width: 800,
            height: 390,
            buttons: {
                "Update Language": function() {
                    processEditLanguage();
                },
                "Cancel": function() {
                    $("#editLanguageForm").dialog("close");
                }
            },
            open: function() {
                setEditLoader();
                loadEditLanguageForm();
                resetOverlays();
            }
        });
        
        // dialog box
        $( "#confirmDelete" ).dialog({
            modal: true,
            autoOpen: false,
            width: 450,
            buttons: {
                "Delete Language": function() {
                    removeLanguage();
                    $("#confirmDelete").dialog("close");
                },
                "Cancel": function() {
                    $("#confirmDelete").dialog("close");
                }
            },
            open: function() {
                resetOverlays();
            }
        });
        
        // dialog box
        $( "#confirmSetAsDefault" ).dialog({
            modal: true,
            autoOpen: false,
            width: 450,
            buttons: {
                "Set As Default Language": function() {
                    setDefaultLanguage();
                    $("#confirmSetAsDefault").dialog("close");
                },
                "Cancel": function() {
                    $("#confirmSetAsDefault").dialog("close");
                }
            },
            open: function() {
                resetOverlays();
            }
        });
    });
    
    function setLoader()
    {
        $('#languageForm').html('Loading, please wait...');
    }
    
    function setEditLoader()
    {
        $('#languageEditForm').html('Loading, please wait...');
    }
    
    function loadAddLanguageForm()
    {
        $.ajax({
            type: "POST",
            url: "ajax/translation_manage_add_form.ajax.php",
            data: { },
            dataType: 'json',
            success: function(json) {
                if(json.error == true)
                {
                    $('#languageForm').html(json.msg);
                }
                else
                {
                    $('#languageForm').html(json.html);
                    $('#translation_flag').ddslick({
                        height: 150,
                        background: '#ffffff',
                        onSelected: function(selectedData){
                            $('#translation_flag_hidden').val(selectedData.selectedData.value);
                        }
                    });
                }
                
            },
            error: function (XMLHttpRequest, textStatus, errorThrown) {
                $('#languageForm').html(XMLHttpRequest.responseText);
            }
        });
    }
    
    function loadEditLanguageForm()
    {
        $.ajax({
            type: "POST",
            url: "ajax/translation_manage_add_form.ajax.php",
            data: { languageId: gEditLanguageId },
            dataType: 'json',
            success: function(json) {
                if(json.error == true)
                {
                    $('#languageEditForm').html(json.msg);
                }
                else
                {
                    $('#languageEditForm').html(json.html);
                    $('#translation_flag').ddslick({
                        height: 150,
                        background: '#ffffff',
                        onSelected: function(selectedData){
                            $('#translation_flag_hidden').val(selectedData.selectedData.value);
                        }
                    });
                }
                
            },
            error: function (XMLHttpRequest, textStatus, errorThrown) {
                $('#languageForm').html(XMLHttpRequest.responseText);
            }
        });
    }
    
    function processAddLanguage()
    {
        // get data
        translation_name = $('#translation_name').val();
        translation_flag = $('#translation_flag_hidden').val();
        
        $.ajax({
            type: "POST",
            url: "ajax/translation_manage_add_process.ajax.php",
            data: { translation_name: translation_name, translation_flag: translation_flag },
            dataType: 'json',
            success: function(json) {
                if(json.error == true)
                {
                    showError(json.msg, 'popupMessageContainer');
                }
                else
                {
                    showSuccess(json.msg);
                    reloadTable();
                    $("#addLanguageForm").dialog("close");
                }
                
            },
            error: function (XMLHttpRequest, textStatus, errorThrown) {
                showError(XMLHttpRequest.responseText, 'popupMessageContainer');
            }
        });

    }
    
    function processEditLanguage()
    {
        // get data
        translation_name = $('#translation_name').val();
        translation_flag = $('#translation_flag_hidden').val();
        
        $.ajax({
            type: "POST",
            url: "ajax/translation_manage_add_process.ajax.php",
            data: { translation_name: translation_name, translation_flag: translation_flag, languageId: gEditLanguageId },
            dataType: 'json',
            success: function(json) {
                if(json.error == true)
                {
                    showError(json.msg, 'popupMessageContainer');
                }
                else
                {
                    showSuccess(json.msg);
                    reloadTable();
                    $("#editLanguageForm").dialog("close");
                }
                
            },
            error: function (XMLHttpRequest, textStatus, errorThrown) {
                showError(XMLHttpRequest.responseText, 'popupMessageContainer');
            }
        });

    }
    
    function addLanguageForm()
    {
        $('#addLanguageForm').dialog('open');
    }
    
    function editLanguageForm(languageId)
    {
        gEditLanguageId = languageId;
        $('#editLanguageForm').dialog('open');
    }

    function reloadTable()
    {
        oTable.fnDraw();
    }
    
    function deleteLanguage(languageId)
    {
        $('#confirmDelete').dialog('open');
        gLanguageId = languageId;
    }
    
    function removeLanguage()
    {
        $.ajax({
            type: "POST",
            url: "ajax/translation_manage_remove.ajax.php",
            data: { languageId: gLanguageId },
            dataType: 'json',
            success: function(json) {
                if(json.error == true)
                {
                    showError(json.msg);
                }
                else
                {
                    showSuccess(json.msg);
                    oTable.fnDraw(); 
                }
                
            },
            error: function (XMLHttpRequest, textStatus, errorThrown) {
                showError(XMLHttpRequest.responseText);
            }
        });
    }
    
    function setDefault(defaultLanguage)
    {
        $('#confirmSetAsDefault').dialog('open');
        gDefaultLanguage = defaultLanguage;
    }
    
    function setDefaultLanguage()
    {
        $.ajax({
            type: "POST",
            url: "ajax/translation_manage_set_default_language.ajax.php",
            data: { defaultLanguage: gDefaultLanguage },
            dataType: 'json',
            success: function(json) {
                if(json.error == true)
                {
                    showError(json.msg);
                }
                else
                {
                    showSuccess(json.msg);
                    oTable.fnDraw(); 
                }
                
            },
            error: function (XMLHttpRequest, textStatus, errorThrown) {
                showError(XMLHttpRequest.responseText);
            }
        });
    }
    
    function setAvailableState(languageId, state)
    {
        $.ajax({
            type: "POST",
            url: "ajax/translation_manage_set_available_state.ajax.php",
            data: { languageId: languageId, state: state },
            dataType: 'json',
            success: function(json) {
                if(json.error == true)
                {
                    showError(json.msg);
                }
                else
                {
                    showSuccess(json.msg);
                    oTable.fnDraw(); 
                }
                
            },
            error: function (XMLHttpRequest, textStatus, errorThrown) {
                showError(XMLHttpRequest.responseText);
            }
        });
    }
</script>

<div class="row clearfix">
    <div class="sectionLargeIcon largeLanguageIcon"></div>
    <div class="widget clearfix">
        <h2>Available Languages</h2>
        <div class="widget_inside">
            <?php echo adminFunctions::compileNotifications(); ?>
            <div class="col_12">
                <table id='fileTable' class='dataTable'>
                    <thead>
                        <tr>
                            <th></th>
                            <th class="align-left"><?php echo UCWords(adminFunctions::t('language_name', 'Language Name')); ?></th>
                            <th class="align-left"><?php echo UCWords(adminFunctions::t('default', 'Default')); ?></th>
                            <th class="align-left"><?php echo UCWords(adminFunctions::t('active', 'Active')); ?></th>
                            <th class="align-left"><?php echo UCWords(adminFunctions::t('actions', 'Actions')); ?></th>
                        </tr>
                    </thead>
                    <tbody>
                    </tbody>
                </table>
            </div>
            <input type="submit" value="Add Language" class="button blue" onClick="addLanguageForm(); return false;"/>
        </div>
    </div>
</div>

<div class="customFilter" id="customFilter" style="display: none;">
    <label>
        Filter Results:
        <input name="filterText" id="filterText" type="text" onKeyUp="reloadTable(); return false;" style="width: 160px;"/>
    </label>
</div>

<div id="addLanguageForm" title="Add Language">
    <span id="languageForm"></span>
</div>

<div id="editLanguageForm" title="Edit Language">
    <span id="languageEditForm"></span>
</div>

<div id="confirmDelete" title="Confirm Action">
    <p>Are you sure you want to delete this language? Any translations will also be removed.</p>
</div>

<div id="confirmSetAsDefault" title="Confirm Action">
    <p>Are you sure you want to set this language as the default on the site?</p>
</div>

<?php
include_once('_footer.inc.php');
?>